@@ -7,8 +7,7 @@
 import numpy as np
 
 from text2vec.utils.rank_bm25 import BM25Okapi
-from text2vec.utils.tokenizer import Tokenizer
-from text2vec.utils.log import logger
+from text2vec.utils.tokenizer import JiebaTokenizer
 
 
 class BM25:
@@ -21,18 +20,17 @@ class BM25:
         self.corpus = corpus
         self.corpus_seg = None
         self.bm25_instance = None
-        self.tokenizer = Tokenizer()
+        self.jieba_tokenizer = JiebaTokenizer()
 
     def init(self):
         if not self.bm25_instance:
             if not self.corpus:
-                logger.error('corpus is None, set corpus with documents.')
                 raise ValueError("must set corpus, which is documents, list of str")
 
             if isinstance(self.corpus, str) or not hasattr(self.corpus, '__len__'):
                 self.corpus = [self.corpus]
 
-            self.corpus_seg = {k: self.tokenizer.tokenize(k) for k in self.corpus}
+            self.corpus_seg = {k: self.jieba_tokenizer.tokenize(k) for k in self.corpus}
             self.bm25_instance = BM25Okapi(corpus=list(self.corpus_seg.values()))
 
     def get_similarities(self, query, n=5):
@@ -55,5 +53,5 @@ class BM25:
         :return: numpy array, scores for query between docs
         """
         self.init()
-        tokens = self.tokenizer.tokenize(query)
+        tokens = self.jieba_tokenizer.tokenize(query)
         return self.bm25_instance.get_scores(query=tokens)
